import { Address } from "ton-core";
import { Blockchain } from "./blockchain/Blockchain.js";
import { BlockchainNetwork } from "./blockchain/BlockchainNetwork.js";
import { JettonTransferAction } from "./blockchain/transactions/actions/JettonTransferAction.js";
import { JettonTransferNotificationAction } from "./blockchain/transactions/actions/JettonTransferNotificationAction.js";
import { TonwebJettonTransactionFetcher } from "./blockchain/transactions/fetchers/TonwebJettonTransactionFetcher.js";
import { Wallet } from "./blockchain/wallets/Wallet.js";
export { JettonWallet } from "./blockchain/wallets/JettonWallet.js";
export { Wallet } from "./blockchain/wallets/Wallet.js";
export { UnknownWallet } from "./blockchain/wallets/UnknownWallet.js";
export { WalletType } from "./blockchain/wallets/WalletType.js";
export { TonCatTransactionFetcher } from "./blockchain/transactions/fetchers/TonCatTransactionFetcher.js";
export { TonwebJettonTransactionFetcher } from "./blockchain/transactions/fetchers/TonwebJettonTransactionFetcher.js";
export { Blockchain } from "./blockchain/Blockchain.js";
export { BlockchainNetwork } from "./blockchain/BlockchainNetwork.js";
const blockchain = new Blockchain(BlockchainNetwork.mainnet);
const address = Address.parse("EQA0S8EuxAf5W8KtkATOM_GBAAodelXHlQw-wtGApj5JLODa");
const account = new Wallet(address);
const fetcher = new TonwebJettonTransactionFetcher(account, blockchain);
fetcher.fetchTransactions(5).then((transactions) => {
    for (const tx of transactions) {
        const action = tx.in_msg?._action;
        if (action instanceof JettonTransferNotificationAction) {
            if (tx.out_msgs[0].destination.address.toString() === "EQBfBWT7X2BHg9tXAxzhz2aKiNTU1tpt5NsiK0uSDW_YAJ67") {
                // tslint:disable-next-line:max-line-length
                console.log("(" + tx.hash + ") Liquidity deposit of " + action?.amount + " (" + action?.sender.address.toString() + ") //" + tx.in_msg?.source.address.toString());
            }
            else {
                // tslint:disable-next-line:max-line-length
                console.log("(" + tx.hash + ") Sell " + action?.amount + " (" + action?.sender.address.toString() + ") //" + tx.in_msg?.source.address.toString());
            }
        }
        else {
            for (const outMsg of tx.out_msgs) {
                if (outMsg._action instanceof JettonTransferAction) {
                    // tslint:disable-next-line:max-line-length
                    console.log("(" + tx.hash + ") Buy " + outMsg._action.amount + " (" + outMsg._action.destination.address.toString() + ") //" + outMsg.destination.address.toString());
                }
            }
        }
    }
});
